AppConfig class

Holds all Paymob credentials and payment configuration for one environment.

Constructors

AppConfig({required String apiKey, required String publicKey, required String secretKey, required List<PaymentMethodConfig> paymentMethods, required List<PaymobIframe> iframes, required int defaultIntegrationId})
const

Properties

apiKey String
final
defaultIntegrationId int
final
hashCode int
The hash code for this object.
no setterinherited
iframes List<PaymobIframe>
final
paymentMethods List<PaymentMethodConfig>
final
publicKey String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretKey String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited