ApiService class

HTTP service implementation using Dio with logging

Implemented types

Constructors

ApiService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAuthToken() → void
Clear authorization header
override
get<T>(String path, {Map<String, dynamic>? queryParameters, Options? options}) Future<Response<T>>
Make a GET request
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post<T>(String path, {dynamic data, Map<String, dynamic>? queryParameters, Options? options}) Future<Response<T>>
Make a POST request
override
postMultipart<T>(String path, {Map<String, dynamic>? fields, Map<String, dynamic>? files, Map<String, dynamic>? queryParameters, Options? options}) Future<Response<T>>
Make a multipart POST request
override
setAuthToken(String token) → void
Set authorization header
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited