CustomerData class

Customer data for Payment Intention

Constructors

CustomerData({required String firstName, required String lastName, required String email, Map<String, dynamic>? extras})
const
CustomerData.fromBillingData(BillingData billingData, {Map<String, dynamic>? extras})
Create from billing data
factory

Properties

email String
final
extras Map<String, dynamic>?
final
firstName String
final
hashCode int
The hash code for this object.
no setterinherited
lastName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited