PaymentIntentionRequest class
Payment Intention Request model for Paymob Unified Checkout
Constructors
-
PaymentIntentionRequest({required int amount, int? expiration, String? specialReference, required String currency, required List<
int> paymentMethods, List<Map< items = const [], required BillingData billingData, required CustomerData customer, Map<String, dynamic> >String, dynamic> ? extras}) -
const
-
PaymentIntentionRequest.create({required double amount, required String currency, required List<
int> paymentMethodIntegrationIds, required BillingData billingData, required CustomerData customer, String? specialReference, int? expiration, List<Map< ? items, Map<String, dynamic> >String, dynamic> ? extras}) -
Create from amount and basic data
factory
Properties
- amount → int
-
final
- billingData → BillingData
-
final
- currency → String
-
final
- customer → CustomerData
-
final
- expiration → int?
-
final
-
extras
→ Map<
String, dynamic> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
Map< String, dynamic> > -
final
-
paymentMethods
→ List<
int> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- specialReference → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON for API request
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited