ExtrasData class

Extras Data model

Constructors

ExtrasData({Map<String, dynamic>? creationExtras, Map<String, dynamic>? confirmationExtras})
const
ExtrasData.fromJson(Map<String, dynamic> json)
factory

Properties

confirmationExtras Map<String, dynamic>?
final
creationExtras Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited