IntentionDetail class
Intention Detail model
Constructors
- IntentionDetail({required int amount, required List items, required String currency, required BillingData billingData})
-
const
-
IntentionDetail.fromJson(Map<
String, dynamic> json) -
factory
Properties
- amount → int
-
final
- billingData → BillingData
-
final
- currency → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- items → List
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited