PaymentIntentionResponse class
Payment Intention Response model for Paymob Unified Checkout
Constructors
-
PaymentIntentionResponse({required List<
PaymentKey> paymentKeys, required int intentionOrderId, required String id, required IntentionDetail intentionDetail, required String clientSecret, required List<PaymentMethod> paymentMethods, String? specialReference, required ExtrasData extras, required bool confirmed, required String status, required String created, dynamic cardDetail, required List cardTokens, required String object}) -
const
-
PaymentIntentionResponse.fromJson(Map<
String, dynamic> json) -
Create from JSON response
factory
Properties
- cardDetail → dynamic
-
final
- cardTokens → List
-
final
- clientSecret → String
-
final
- confirmed → bool
-
final
- created → String
-
final
- extras → ExtrasData
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- intentionDetail → IntentionDetail
-
final
- intentionOrderId → int
-
final
- object → String
-
final
-
paymentKeys
→ List<
PaymentKey> -
final
-
paymentMethods
→ List<
PaymentMethod> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- specialReference → String?
-
final
- status → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited