PaymentKey class

Payment Key model

Constructors

PaymentKey({required int integration, required String key, String? gatewayType, int? iframeId, required int orderId, String? redirectionUrl, required bool saveCard})
const
PaymentKey.fromJson(Map<String, dynamic> json)
factory

Properties

gatewayType String?
final
hashCode int
The hash code for this object.
no setterinherited
iframeId int?
final
integration int
final
key String
final
orderId int
final
redirectionUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveCard bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited