PaymentMethod class

Payment Method model

Constructors

PaymentMethod({required int integrationId, String? alias, required String name, required String methodType, required String currency, required bool live, required bool useCvcWithMoto})
const
PaymentMethod.fromJson(Map<String, dynamic> json)
factory

Properties

alias String?
final
currency String
final
hashCode int
The hash code for this object.
no setterinherited
integrationId int
final
live bool
final
methodType String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useCvcWithMoto bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited