PaymentLinkRequest class
Model for payment link creation request
Constructors
-
PaymentLinkRequest({required int amountCents, required List<
String> paymentMethods, required String email, required String fullName, required String phoneNumber, String? description, bool isLive = true, String? paymentLinkImage, String? referenceId}) -
const
-
PaymentLinkRequest.fromAmount({required double amount, required List<
String> paymentMethods, required String email, required String fullName, required String phoneNumber, String? description, bool isLive = true, String? paymentLinkImage, String? referenceId}) -
Create PaymentLinkRequest from amount in currency units
factory
Properties
- amountCents → int
-
Amount in cents
final
- description → String?
-
Payment description
final
- email → String
-
Customer email
final
- fullName → String
-
Customer full name
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isLive → bool
-
Whether this is a live payment (true) or test (false)
final
- paymentLinkImage → String?
-
Payment link image file path (optional)
final
-
paymentMethods
→ List<
String> -
Payment methods (integration IDs)
final
- phoneNumber → String
-
Customer phone number
final
- referenceId → String?
-
Reference ID for tracking (optional)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFormData(
) → Map< String, String> - Convert to form data for multipart request
-
toJson(
) → Map< String, dynamic> - Convert to JSON for API request
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override