PaymentLinkResponse class

Model for payment link creation response

Constructors

PaymentLinkResponse({required int id, String? currency, required ClientInfo clientInfo, String? referenceId, required int amountCents, required String state, String? description, required DateTime createdAt, DateTime? expiresAt, DateTime? paidAt, required String clientUrl, required int origin, String? merchantStaffTag, String? paymentLinkImage, required int order})
const
PaymentLinkResponse.fromJson(Map<String, dynamic> json)
Create PaymentLinkResponse from JSON
factory

Properties

amount double
Get amount in currency units
no setter
amountCents int
Amount in cents
final
clientInfo ClientInfo
Client information
final
clientUrl String
Client URL for payment
final
createdAt DateTime
Creation timestamp
final
currency String?
Currency code
final
description String?
Payment description
final
expiresAt DateTime?
Expiration timestamp
final
hashCode int
The hash code for this object.
no setteroverride
id int
Payment link ID
final
isExpired bool
Check if payment link is expired
no setter
isPaid bool
Check if payment is completed
no setter
merchantStaffTag String?
Merchant staff tag
final
order int
Order ID
final
origin int
Origin identifier
final
paidAt DateTime?
Payment completion timestamp (null if not paid)
final
paymentLinkImage String?
Payment link image URL
final
referenceId String?
Reference ID
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String
Payment state
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override