PaymentMethodConfig class

Configuration class for payment methods with their identifiers

Constructors

PaymentMethodConfig({required PaymobPaymentMethod paymentMethod, required String identifier, required String integrationId, required String customSubtype, required String displayName, required String description})
const

Properties

customSubtype String
Custom subtype for this payment method
final
description String
Description for this payment method
final
displayName String
Display name for this payment method
final
hashCode int
The hash code for this object.
no setteroverride
identifier String
The identifier for this payment method (can be int or string)
final
integrationId String
Integration ID as string
final
paymentMethod PaymobPaymentMethod
The payment method
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override