PaymobIframe class
Represents a Paymob iframe configuration
Constructors
- PaymobIframe({required int iframeId, required int integrationId, String? name, String? description})
- Constructs a PaymobIframe object with the provided data.
-
PaymobIframe.fromJson(Map<
String, dynamic> json) -
Creates a PaymobIframe from a JSON map.
factory
Properties
- description → String?
-
Optional description for the iframe
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- iframeId → int
-
The iframe ID from Paymob dashboard
final
- integrationId → int
-
The integration ID for this iframe
final
- name → String?
-
Optional name for the iframe (for reference)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts the PaymobIframe object into a Map<String, dynamic> for JSON serialization.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override