PaymobPaymentMethod enum

Enum representing different Paymob payment methods

Inheritance
Available extensions

Values

applePay → const PaymobPaymentMethod

Apple Pay

valu → const PaymobPaymentMethod

ValU installment service

bankInstallments → const PaymobPaymentMethod

Bank Installments

souhoolaV3 → const PaymobPaymentMethod

Souhoola V3

amanV3 → const PaymobPaymentMethod

Aman V3

forsa → const PaymobPaymentMethod

Forsa

premium → const PaymobPaymentMethod

Premium

contact → const PaymobPaymentMethod

Contact

halan → const PaymobPaymentMethod

HALAN

sympl → const PaymobPaymentMethod

SYMPL

kiosk → const PaymobPaymentMethod

Kiosk

wallet → const PaymobPaymentMethod

Generic wallet

custom → const PaymobPaymentMethod

Custom payment method

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PaymobPaymentMethod>
A constant List of the values in this enum, in order of their declaration.