UnifiedCheckoutConfig class

Unified Checkout Configuration model

Constructors

UnifiedCheckoutConfig({required String publicKey, required String clientSecret, String? title, String? description})
const
UnifiedCheckoutConfig.fromPaymentIntention({required String publicKey, required PaymentIntentionResponse response, String? title, String? description})
Create from Payment Intention Response
factory

Properties

checkoutUrl String
Generate Unified Checkout URL
no setter
clientSecret String
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
isValid bool
Validate configuration
no setter
publicKey String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited