ApiConstants class
API constants for Paymob integration
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- acceptBaseUrl → const String
- acceptV1BaseUrl → const String
- defaultCurrency → const String
-
defaultHeaders
→ const Map<
String, String> - defaultUserTokenExpiration → const int
- keys → const String
- order → const String
- paymentIntention → const String
- paymentLinks → const String
- wallet → const String