ClientInfo class

Client information model

Constructors

ClientInfo({required String fullName, required String email, required String phoneNumber})
const
ClientInfo.fromJson(Map<String, dynamic> json)
Create ClientInfo from JSON
factory

Properties

email String
Email address
final
fullName String
Full name
final
hashCode int
The hash code for this object.
no setteroverride
phoneNumber String
Phone number
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override