PaymentApiService class

Service for handling payment API operations

Constructors

PaymentApiService(ApiServiceInterface _apiService)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAuth() → void
Clear authentication data
createOrder(double amount, String currency) Future<int>
Create a new order
createPaymentIntention({required PaymentIntentionRequest request, required String secretKey}) Future<PaymentIntentionResponse>
Create Payment Intention for Unified Checkout
Create a payment link
getAuthenticationToken(String apiKey) Future<String>
Get API authentication token
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPaymentToken({required double amount, required String currency, required String integrationId, required BillingData billingData, int userTokenExpiration = ApiConstants.defaultUserTokenExpiration}) Future<String>
Request payment token
requestPayUrl({required String paymentToken, String? identifier, String? subtype}) Future<String>
Request wallet URL
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited